from setuptools import setup

setup(name='distributions_types',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['distributions_types'],
      author='Shubhangi Agrawal',
      zip_safe=False)
